@@ -340,12 +340,18 @@ class EKSPipe(Pipe):
             self.json_logs.append(fmt_log)
 
 class ConfigSnapshotPipe(Pipe):
-    def __init__(self, app_id = ''):
+    def __init__(self):
         super().__init__()
         self.bytes_so_far = 0
-        self.app_id = app_id
+        self.app_id = get_app_id()
 
     def push(self, content):
+        content["Cloud"] = "aws"
+        content["ResourceContainer"] = content["awsAccountID"]
+        content["Region"] = content["awsRegion"]
+        content["Service"] = content["resourceType"].split('::')[1]
+        content["ResourceName"] = content["tags"]["name"]
+        content["Config"] = content
         self.json_logs.append(content)
         self.bytes_so_far += len(dumps(content))
         if self.bytes_so_far >= (0.1 * 1048576):
@@ -355,17 +361,29 @@ class ConfigSnapshotPipe(Pipe):
             return False
 
 class ConfigChangePipe(Pipe):
-    def __init__(self, app_id = ''):
+    def __init__(self):
         super().__init__()
-        self.app_id = app_id
+        self.app_id = get_app_id()
 
     def push(self, content):
-        with gzip.GzipFile(fileobj=BytesIO(content), mode="rb") as decompress_stream:
-            data = load(decompress_stream)     
-            items = data['configurationItems']
-            for item in items:
-                self.json_logs.append(item)
-
+        items = content['Records']
+        for item in items:
+            item["body"] = loads(item["body"])
+            output = loads(item["body"]["Message"])
+            if output["messageType"] != "ConfigurationItemChangeNotification":
+                continue
+            output["Cloud"] = "aws"
+            output["ResourceContainer"] = output["configurationItem"]["awsAccountId"]
+            output["Region"] = output["configurationItem"]["awsRegion"]
+            output["Service"] = output["configurationItem"]["resourceType"].split("::")[1]
+            output["ResourceType"] = output["configurationItem"]["resourceType"]
+            output["ResourceID"] = output["configurationItem"]["resourceId"]
+            try:
+                output["ResourceName"] = output["configurationItem"]["resourceName"]
+            except:
+                pass
+            output["Config"] = output["configurationItem"]
+            self.json_logs.append(output)
 
 def DataPipe():
     pipe_selector = {
@@ -381,11 +399,11 @@ def DataPipe():
     }
     return pipe_selector[get_app_id()]()
 
-def ConfigPipe(app_id='aws_config', one_time=True):
+def ConfigPipe(one_time=True):
     if one_time:
-        return ConfigSnapshotPipe(app_id=app_id)
+        return ConfigSnapshotPipe()
     else: 
-        return ConfigChangePipe(app_id=app_id)
+        return ConfigChangePipe()
 
 
     
